"""
Module containing device capability related information.
All info in this module was pulled from the Cync app, and should not be manually modified
unless the changes come directly from the app's information.

Note that just because a device is listed here, does not necessarily mean this library supports it.
This is here to establish a complete list of capabilities so implementing devices in the future has fewer steps.

List last updated from Android app version 6.20.0.54634-60b11b1f5
"""

from enum import Enum

class CyncCapability(Enum):
    """List of all possible capabilities for a device."""
    COMMISSION = "Commission"
    EDIT_NAME = "EditName"
    DELETE = "Delete"
    SET_LOAD_TYPE = "SetLoadType"
    FACTORY_RESET = "FactoryReset"
    SET_MESH_ADDRESS = "SetMeshAddress"
    NO_MESH = "NoMesh"
    SIG_MESH = "SigMesh"
    CHECK_WIFI_OTA = "CheckWifiOTA"
    START_WIFI_OTA = "StartWifiOTA"
    WIFI_OTA_MODE = "WifiOTAMode"
    ON_OFF = "OnOff"
    DIMMING = "Dimming"
    CCT_COLOR = "CctColor"
    RGB_COLOR = "RgbColor"
    REVEAL_LIGHT = "RevealLight"
    LIGHT_SHOW = "LightShow"
    MUSIC_SHOW = "MusicShow"
    SUNRISE_SUNSET = "SunriseSunset"
    FAN_SPEED = "FanSpeed"
    SLEEP = "Sleep"
    COMBO = "Combo"
    ASSIGN_TO_GROUP = "AssignToGroup"
    SCENE_CONTROL = "SceneControl"
    AUTOMATION_CONTROL = "AutomationControl"
    PRODUCT_MODEL_INFO = "ProductModelInfo"
    MAC_ADDRESS_INFO = "MacAddressInfo"
    FIRMWARE_INFO = "FirmwareInfo"
    GET_TIME = "GetTime"
    SET_TIME = "SetTime"
    GET_WIFI = "GetWifi"
    CHANGE_WIFI = "ChangeWifi"
    ALEXA_SETTINGS = "AlexaSettings"
    ALEXA_SKILL_CONTROL = "AlexaSkillControl"
    GOOGLE_ACTION_CONTROL = "GoogleActionControl"
    HOME_KIT_CONTROL = "HomeKitControl"
    INNER_RING_LIGHT = "InnerRingLight"
    LIGHT_RING_INDICATOR = "LightRingIndicator"
    IDENTIFY_INDICATOR = "IdentifyIndicator"
    WIFI_DISCONNECTED_INDICATOR = "WifiDisconnectedIndicator"
    BATTERY_LOW_INDICATOR = "BatteryLowIndicator"
    BUTTON_PRESSED_INDICATOR = "ButtonPressedIndicator"
    MOTION_SENSOR_CONFIGURATION = "MotionSensorConfiguration"
    MOTION_SENSOR_STATE = "MotionSensorState"
    MOTION_SENSOR_SENSITIVITY = "MotionSensorSensitivity"
    AMBIENT_LIGHT_SENSOR_STATE = "AmbientLightSensorState"
    AMBIENT_LIGHT_SENSOR_THRESHOLD = "AmbientLightSensorThreshold"
    MOTION_BROADCASTER = "MotionBroadcaster"
    MOTION_OBSERVER = "MotionObserver"
    EDIT_TIMEOUT_PERIOD = "EditTimeoutPeriod"
    EDIT_DEACTIVATION_PERIOD = "EditDeactivationPeriod"
    EDIT_LED_INDICATOR_BRIGHTNESS = "EditLedIndicatorBrightness"
    LOAD_BRIGHTNESS_INDICATOR = "LoadBrightnessIndicator"
    LED_INDICATOR = "LedIndicator"
    LOAD_BRIGHTNESS_TRIM = "LoadBrightnessTrim"
    CAN_ACT_AS_BLE_PROXY = "CanActAsBleProxy"
    CAN_ACT_AS_WIFI_PROXY = "CanActAsWifiProxy"
    DATA_POINT_PROTOCOL = "DataPointProtocol"
    NEUTRAL_WIRE = "NeutralWire"
    STRIP_LENGTH_DETECTION = "StripLengthDetection"
    SEGMENTED_CONTROL = "SegmentedControl"
    SEGMENTED_CONTROL_GRADIENT = "SegmentedControlGradient"
    TILE_LAYOUT = "TileLayout"
    MICROPHONE_SENSITIVITY = "MicrophoneSensitivity"
    CUSTOMIZABLE_BUTTONS = "CustomizableButtons"
    ON_OFF_OBSERVER = "OnOffObserver"
    OUTDOOR = "Outdoor"

# Map of device type IDs to their capabilities.
# Human-readable device type names have been added as comments for convenience.
DEVICE_CAPABILITIES = {
    # FullColorStripGen1Standalone
    8: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
        CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
        CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
        CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
        CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
        CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
        CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
        CyncCapability.SUNRISE_SUNSET},
    # CLifeA19Gen2StandaloneCECTier2
    9: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
        CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
        CyncCapability.COMBO, CyncCapability.DIMMING, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
        CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
        CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
        CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
        CyncCapability.SUNRISE_SUNSET},
    # CSleepA19Gen2StandaloneCECTier2
    10: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30Gen2StandaloneCECTier2
    11: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CLifeA19TCOGen2Standalone
    13: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CSleepA19TCOGen2Standalone
    14: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.CCT_COLOR, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30TCOGen2Standalone
    15: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CLifeA19Gen2GoogleBundle
    17: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CLifeA19Gen2MadeForGoogle
    18: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.COMBO, CyncCapability.DIMMING, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CSleepA19Gen2MadeForGoogle
    19: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30Gen2MadeForGoogle
    20: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # FullColorA19Gen1MadeForGoogle
    21: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorBR30Gen1MadeForGoogle
    22: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorStripGen1MadeForGoogle
    23: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
         CyncCapability.SUNRISE_SUNSET},
    # CLifeA19Gen2MadeForGoogleCECTier2
    24: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.COMBO, CyncCapability.DIMMING, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CSleepA19Gen2MadeForGoogleCECTier2
    25: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30Gen2MadeForGoogleCECTier2
    26: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CLifeA19TCOGen2MadeForGoogle
    27: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CSleepA19TCOGen2MadeForGoogle
    28: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30TCOGen2MadeForGoogle
    29: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # FullColorA19TCOGen2Standalone
    30: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.FACTORY_RESET, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorA19TCOGen2MadeForGoogle
    31: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorBR30TCOGen2Standalone
    32: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorBR30TCOGen2MadeForGoogle
    33: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorStripTCOGen2Standalone
    34: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FullColorStripTCOGen2MadeForGoogle
    35: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.LIGHT_SHOW},
    # FourWireSwitchDimmerGen2
    36: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchMotionSensingDimmerGen2
    37: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.MOTION_SENSOR_CONFIGURATION,
         CyncCapability.MOTION_SENSOR_STATE, CyncCapability.MOTION_SENSOR_SENSITIVITY,
         CyncCapability.AMBIENT_LIGHT_SENSOR_STATE, CyncCapability.AMBIENT_LIGHT_SENSOR_THRESHOLD,
         CyncCapability.MOTION_BROADCASTER, CyncCapability.EDIT_TIMEOUT_PERIOD, CyncCapability.EDIT_DEACTIVATION_PERIOD,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE,
         CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.WIFI_DISCONNECTED_INDICATOR,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchCircleGen2
    38: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
         CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchPaddleGen2
    39: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchToggleGen2
    40: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # SingleChipFullColorUnderCabinetBarFixture12InchGen1
    41: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorUnderCabinetBarFixture18InchGen1
    42: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorUnderCabinetBarFixture24InchGen1
    43: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorUnderCabinetPuckFixtureGen1
    44: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorRecessedCanRetrofitFixture6InchGen1
    46: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorRecessedCanRetrofitFixture6InchGen1NonMatter
    47: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # FourWireSwitchDimmerGen1
    48: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
         CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchMotionSensingDimmerGen1
    49: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
         CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR,
         CyncCapability.MOTION_SENSOR_CONFIGURATION, CyncCapability.MOTION_SENSOR_STATE,
         CyncCapability.MOTION_SENSOR_SENSITIVITY, CyncCapability.AMBIENT_LIGHT_SENSOR_STATE,
         CyncCapability.AMBIENT_LIGHT_SENSOR_THRESHOLD, CyncCapability.MOTION_BROADCASTER,
         CyncCapability.EDIT_TIMEOUT_PERIOD, CyncCapability.EDIT_DEACTIVATION_PERIOD, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchPaddleGen1
    51: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchToggleGen1
    52: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchCircleGen1
    53: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # NoNeutralSwitchGen1Dimmer
    55: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.DIMMING,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
         CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # NoNeutralSwitchGen1MotionSensingDimmer
    56: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
         CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR,
         CyncCapability.MOTION_SENSOR_CONFIGURATION, CyncCapability.MOTION_SENSOR_STATE,
         CyncCapability.MOTION_SENSOR_SENSITIVITY, CyncCapability.AMBIENT_LIGHT_SENSOR_STATE,
         CyncCapability.AMBIENT_LIGHT_SENSOR_THRESHOLD, CyncCapability.MOTION_BROADCASTER,
         CyncCapability.EDIT_TIMEOUT_PERIOD, CyncCapability.EDIT_DEACTIVATION_PERIOD, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # NoNeutralSwitchGen1SwitchPaddle
    57: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # NoNeutralSwitchGen1SwitchToggle
    58: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # NoNeutralSwitchGen1SwitchCircle
    59: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # FourWireSwitchPaddleTCOGen1
    61: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchToggleTCOGen1
    62: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchCircleTCOGen1
    63: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.NEUTRAL_WIRE},
    # PlugGen1
    64: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # PlugTCOGen2
    65: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # PlugGen2
    66: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # PlugOutdoorGen1
    67: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.OUTDOOR},
    # SingleChipPlug
    68: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # PlugOutdoorGen2
    69: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
         CyncCapability.OUTDOOR},
    # SingleChipFullColorIndoorPremiumLightStrip16ftGen3
    71: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.STRIP_LENGTH_DETECTION,
         CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorIndoorPremiumLightStrip32ftGen3
    72: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.STRIP_LENGTH_DETECTION,
         CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorOutdoorNeonLightStrip16ft
    73: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR,
         CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorOutdoorNeonLightStrip32ft
    74: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR,
         CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorOutdoorCafeLights24ftGen1
    75: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR, CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorOutdoorCafeLights48ftGen1
    76: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
         CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
         CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
         CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR, CyncCapability.MICROPHONE_SENSITIVITY},
    # SolGen1Standalone
    80: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SETTINGS,
         CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.INNER_RING_LIGHT,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER},
    # FanSpeedSwitchGen1
    81: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
         CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.FAN_SPEED, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
         CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.WIFI_DISCONNECTED_INDICATOR,
         CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.SUNRISE_SUNSET},
    # CLifeBR30Gen1Standalone
    82: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # CSleepBR30Gen2Standalone
    83: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.ON_OFF,
         CyncCapability.DIMMING, CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # WireFreeMotionSensor
    96: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
         CyncCapability.FACTORY_RESET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.IDENTIFY_INDICATOR,
         CyncCapability.BATTERY_LOW_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR,
         CyncCapability.MOTION_SENSOR_CONFIGURATION, CyncCapability.MOTION_SENSOR_STATE,
         CyncCapability.MOTION_SENSOR_SENSITIVITY, CyncCapability.AMBIENT_LIGHT_SENSOR_STATE,
         CyncCapability.AMBIENT_LIGHT_SENSOR_THRESHOLD, CyncCapability.MOTION_BROADCASTER,
         CyncCapability.EDIT_TIMEOUT_PERIOD, CyncCapability.EDIT_DEACTIVATION_PERIOD, CyncCapability.SLEEP},
    # SingleChipFullColorBulbST19Gen2
    97: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbG25Gen2
    98: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
         CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
         CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
         CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
         CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
         CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbST19Gen2
    99: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
         CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
         CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
         CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
         CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
         CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
         CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
         CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbG25Gen2
    100: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbBCGen1
    101: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbBMGen1
    102: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealSoftWhiteBulbA19Gen2
    103: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.REVEAL_LIGHT, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbPAR38OutdoorGen2
    104: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.OUTDOOR},
    # SingleChipFullColorBulbA21Gen2
    105: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorBulbA19Gen2
    107: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorBulbBR30Gen2
    108: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorBulbA21Gen2
    109: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorIndoorValueLightStrip16ftGen3
    110: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER},
    # PlugOutdoorGen3
    111: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.OUTDOOR},
    # WireFreeSmartSwitchDimmer
    112: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BATTERY_LOW_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.SLEEP},
    # WireFreeSmartSwitchDimmerPlusColorController
    113: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BATTERY_LOW_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.SLEEP},
    # WireFreeSmartRemoteDimmer
    114: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BATTERY_LOW_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.SLEEP},
    # WireFreeSmartRemoteDimmerPlusColorController
    115: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BATTERY_LOW_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.SLEEP},
    # FourWireSwitchDimmerGen3
    116: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchMotionSensingDimmerGen3
    117: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.MOTION_SENSOR_CONFIGURATION,
          CyncCapability.MOTION_SENSOR_STATE, CyncCapability.MOTION_SENSOR_SENSITIVITY,
          CyncCapability.AMBIENT_LIGHT_SENSOR_STATE, CyncCapability.AMBIENT_LIGHT_SENSOR_THRESHOLD,
          CyncCapability.MOTION_BROADCASTER, CyncCapability.EDIT_TIMEOUT_PERIOD,
          CyncCapability.EDIT_DEACTIVATION_PERIOD, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchCircleGen3
    118: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.LIGHT_RING_INDICATOR,
          CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
          CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchPaddleGen3
    119: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # FourWireSwitchToggleGen3
    120: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.COMBO,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.SET_LOAD_TYPE,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # FanSpeedSwitchGen2
    121: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.FAN_SPEED,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE,
          CyncCapability.LED_INDICATOR, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.WIFI_DISCONNECTED_INDICATOR,
          CyncCapability.LIGHT_RING_INDICATOR, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # ThermostatGen2
    122: {CyncCapability.NO_MESH, CyncCapability.DATA_POINT_PROTOCOL, CyncCapability.COMMISSION,
          CyncCapability.EDIT_NAME, CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME,
          CyncCapability.GET_TIME, CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.IDENTIFY_INDICATOR},
    # SingleChipFullColorIndoorValueLightStrip32ftGen3
    123: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER},
    # FourWireSwitchKeypadDimmerGen1
    124: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.IDENTIFY_INDICATOR, CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR,
          CyncCapability.EDIT_LED_INDICATOR_BRIGHTNESS, CyncCapability.LOAD_BRIGHTNESS_INDICATOR,
          CyncCapability.LOAD_BRIGHTNESS_TRIM, CyncCapability.ON_OFF_OBSERVER, CyncCapability.SET_LOAD_TYPE,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE, CyncCapability.CUSTOMIZABLE_BUTTONS},
    # FourWireSwitchPaddleDimmerGen1
    125: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.IDENTIFY_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.WIFI_OTA_MODE, CyncCapability.LED_INDICATOR, CyncCapability.EDIT_LED_INDICATOR_BRIGHTNESS,
          CyncCapability.LOAD_BRIGHTNESS_INDICATOR, CyncCapability.LOAD_BRIGHTNESS_TRIM, CyncCapability.ON_OFF_OBSERVER,
          CyncCapability.SET_LOAD_TYPE, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.NEUTRAL_WIRE},
    # DirectConnectSoftWhiteBulbA19
    128: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # DirectConnectTunableWhiteBulbA19
    129: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # DirectConnectTunableWhiteBulbBR30
    130: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # DirectConnectFullColorBulbA19
    131: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # DirectConnectFullColorBulbBR30
    132: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # DirectConnectFullColorLightStrip
    133: {CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME, CyncCapability.GET_WIFI,
          CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING, CyncCapability.COMBO,
          CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteA19
    134: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipTunableWhiteA19
    135: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipTunableWhiteBR30
    136: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbA19
    137: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.LIGHT_SHOW},
    # SingleChipFullColorBulbBR30
    138: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorIndoorValueLightStripGen2
    139: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.SUNRISE_SUNSET, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER},
    # SingleChipFullColorBulbPAR38Outdoor
    140: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET,
          CyncCapability.OUTDOOR},
    # SingleChipFullColorOutdoorPremiumLightStrip16ftGen2
    141: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorWafer4InchGen1
    142: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorWafer6InchGen1
    143: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipTunableWhiteWafer4InchGen1
    144: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipTunableWhiteWafer6InchGen1
    145: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbST19Gen1
    146: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbG25Gen1
    147: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbST19Gen1
    148: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbG25Gen1
    149: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbBCGen1
    150: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipSoftWhiteBulbBMGen1
    151: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealSoftWhiteBulbA19
    152: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.REVEAL_LIGHT, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorBulbA19
    153: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorBulbBR30
    154: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW,
          CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorDynamicEffectsBulbA19
    155: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.LIGHT_SHOW, CyncCapability.MUSIC_SHOW, CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipRevealFullColorBulbA21
    156: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorDynamicEffectsBulbBR30
    157: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.LIGHT_SHOW, CyncCapability.MUSIC_SHOW, CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorIndoorPremiumLightStripGen2
    158: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.STRIP_LENGTH_DETECTION,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorOutdoorPremiumLightStrip32ftGen2
    159: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.OUTDOOR,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorBulbA21
    160: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER,
          CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorWafer2InchGen1
    161: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorGimbalWafer4InchGen1
    162: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorGimbalWafer6InchGen1
    163: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorHighLumenWafer4InchGen1
    164: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorHighLumenWafer6InchGen1
    165: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorDynamicEffectsNeonLightStrip10ftGen1
    166: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.STRIP_LENGTH_DETECTION,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorDynamicEffectsNeonLightStrip16ftGen1
    167: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.LIGHT_SHOW,
          CyncCapability.MUSIC_SHOW, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.SEGMENTED_CONTROL_GRADIENT, CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY,
          CyncCapability.CAN_ACT_AS_WIFI_PROXY, CyncCapability.MOTION_OBSERVER, CyncCapability.STRIP_LENGTH_DETECTION,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipFullColorDynamicEffectsHexagonLightTileGen1
    168: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.SEGMENTED_CONTROL,
          CyncCapability.LIGHT_SHOW, CyncCapability.MUSIC_SHOW, CyncCapability.TILE_LAYOUT,
          CyncCapability.MICROPHONE_SENSITIVITY},
    # SingleChipRevealFullColorWafer4InchGen1
    169: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorWafer6InchGen1
    170: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbA19Gen3
    171: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.LIGHT_SHOW},
    # SingleChipPlugTCOGen1
    172: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.IDENTIFY_INDICATOR,
          CyncCapability.BUTTON_PRESSED_INDICATOR, CyncCapability.CHECK_WIFI_OTA, CyncCapability.START_WIFI_OTA,
          CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.WIFI_DISCONNECTED_INDICATOR, CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbBR30Gen3
    173: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.LIGHT_SHOW},
    # SingleChipRevealFullColorWafer4InchGen2
    174: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorWafer6InchGen2
    175: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorWafer2InchGen2
    177: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorHighLumenWafer4InchGen2
    180: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipRevealFullColorHighLumenWafer6InchGen2
    181: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.REVEAL_LIGHT,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL,
          CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO,
          CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.LIGHT_SHOW, CyncCapability.SUNRISE_SUNSET},
    # SingleChipFullColorBulbA19ClearSpiralGen1
    182: {CyncCapability.SIG_MESH, CyncCapability.SET_MESH_ADDRESS, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME,
          CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME, CyncCapability.GET_TIME,
          CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI, CyncCapability.ON_OFF, CyncCapability.DIMMING,
          CyncCapability.COMBO, CyncCapability.CCT_COLOR, CyncCapability.RGB_COLOR, CyncCapability.ASSIGN_TO_GROUP,
          CyncCapability.SCENE_CONTROL, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.HOME_KIT_CONTROL, CyncCapability.CHECK_WIFI_OTA,
          CyncCapability.START_WIFI_OTA, CyncCapability.CAN_ACT_AS_BLE_PROXY, CyncCapability.CAN_ACT_AS_WIFI_PROXY,
          CyncCapability.MOTION_OBSERVER, CyncCapability.SUNRISE_SUNSET, CyncCapability.LIGHT_SHOW},
    # ThermostatGen1
    224: {CyncCapability.NO_MESH, CyncCapability.DATA_POINT_PROTOCOL, CyncCapability.COMMISSION,
          CyncCapability.EDIT_NAME, CyncCapability.DELETE, CyncCapability.FACTORY_RESET, CyncCapability.SET_TIME,
          CyncCapability.GET_TIME, CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI,
          CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO, CyncCapability.MAC_ADDRESS_INFO,
          CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL, CyncCapability.GOOGLE_ACTION_CONTROL,
          CyncCapability.IDENTIFY_INDICATOR},
    # CameraIndoorGen1
    240: {CyncCapability.NO_MESH, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL},
    # CameraOutdoorWiredGen1
    241: {CyncCapability.NO_MESH, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.OUTDOOR},
    # CameraOutdoorBatteryGen1
    242: {CyncCapability.NO_MESH, CyncCapability.COMMISSION, CyncCapability.EDIT_NAME, CyncCapability.DELETE,
          CyncCapability.FACTORY_RESET, CyncCapability.GET_WIFI, CyncCapability.CHANGE_WIFI,
          CyncCapability.ASSIGN_TO_GROUP, CyncCapability.AUTOMATION_CONTROL, CyncCapability.PRODUCT_MODEL_INFO,
          CyncCapability.MAC_ADDRESS_INFO, CyncCapability.FIRMWARE_INFO, CyncCapability.ALEXA_SKILL_CONTROL,
          CyncCapability.GOOGLE_ACTION_CONTROL, CyncCapability.OUTDOOR},
}